from dash import html, dcc, Input, Output

import data_store
from app import app
from tab_data_inspection import create_tab_data_inspection
from tab_input_selection import create_tab_input_selection
from tab_compare import create_tab_compare

data_store.all_data = None
data_store.selected_directory = None

app.layout = html.Div(
    id='root',
    children=[html.Div([
        dcc.Tabs(
            id='tabs',
            value='1',
            children=[
                dcc.Tab(label='Select input', value='1'),
                dcc.Tab(label='Inspect', value='2'),
                dcc.Tab(label='Compare', value='3'),
                dcc.Tab(label='Harmonize', value='4'),
                dcc.Tab(label='Estimate', value='5'),
            ],
            vertical=False
        ),
        # Load all tab contents here but control visibility through a callback
        html.Div(
            [
                html.Div(create_tab_input_selection(), id='tab-1-content', style={'display': 'block'}),
                html.Div(create_tab_data_inspection(), id='tab-2-content', style={'display': 'none'}),
                html.Div(create_tab_compare(), id='tab-3-content', style={'display': 'none'}),
                html.Div("asdf", id='tab-4-content', style={'display': 'none'}),
                html.Div("Estimate content goes here", id='tab-5-content', style={'display': 'none'}),
            ],
            id='tab-content-container'
        )
    ], id='main-container')])


# Callback to toggle visibility based on selected tab
@app.callback(
    [Output(f'tab-{i}-content', 'style') for i in range(1, 6)],
    [Input('tabs', 'value')]
)
def display_content(selected_tab):
    # Set 'display' to 'block' for the selected tab and 'none' for others
    return [{'display': 'block' if selected_tab == str(i) else 'none'} for i in range(1, 6)]


if __name__ == '__main__':
    app.run_server(debug=True)



import dash
from dash import Dash, html, dcc, Input, Output
from components.plots import violin_plot
from components.plots import box_plot
from components.plots import scatter_plot
from app import app


def create_tab_compare():
    return html.Div([

        # Plot selection
        html.Div([
            html.Button("Violin Plot", id='btn-violin', n_clicks=0, className='plot-button'),
            html.Button("Box Plot", id='btn-box', n_clicks=0, className='plot-button'),
            html.Button("Scatter Plot", id='btn-scatter', n_clicks=0, className='plot-button'),
        ], style={'display': 'flex', 'gap': '10px', 'justify-content': 'center'}),

        # Plot container
        html.Div([
            html.Div(violin_plot.layout, id='plot-1', style={'display': 'block'}),
            html.Div(box_plot.layout, id='plot-2', style={'display': 'none'}),
            html.Div(scatter_plot.layout, id='plot-3', style={'display': 'none'})
        ], id='plot-container')
    ])


# Callback to toggle visibility based on selected plot
@app.callback(
    [Output(f'plot-{i}', 'style') for i in range(1, 4)],
    [Input('btn-violin', 'n_clicks'),
     Input('btn-box', 'n_clicks'),
     Input('btn-scatter', 'n_clicks')]
)
def display_content(btn_violin, btn_box, btn_scatter):
    # Determine which button has been clicked most recently
    ctx = dash.callback_context
    if not ctx.triggered:
        return [{'display': 'block'}, {'display': 'none'}, {'display': 'none'}]  # Default: show violin plot
    button_id = ctx.triggered[0]['prop_id'].split('.')[0]

    # Map buttons to plots
    if button_id == 'btn-violin':
        return [{'display': 'block'}, {'display': 'none'}, {'display': 'none'}]
    elif button_id == 'btn-box':
        return [{'display': 'none'}, {'display': 'block'}, {'display': 'none'}]
    elif button_id == 'btn-scatter':
        return [{'display': 'none'}, {'display': 'none'}, {'display': 'block'}]

    return [{'display': 'block'}, {'display': 'none'}, {'display': 'none'}]  # Fallback


# Callback to update button styles (highlight the selected button)
@app.callback(
    Output('btn-violin', 'className'),
    Output('btn-box', 'className'),
    Output('btn-scatter', 'className'),
    Input('btn-violin', 'n_clicks'),
    Input('btn-box', 'n_clicks'),
    Input('btn-scatter', 'n_clicks')
)
def update_button_styles(btn_violin, btn_box, btn_scatter):
    plot_type = get_plot_type(btn_violin, btn_box, btn_scatter)

    # Highlight the selected button
    return (
        'plot-button selected' if plot_type == 'violin' else 'plot-button',
        'plot-button selected' if plot_type == 'box' else 'plot-button',
        'plot-button selected' if plot_type == 'scatter' else 'plot-button'
    )


def get_plot_type(btn_violin, btn_box, btn_scatter):
    # Determine which button was clicked most recently
    ctx = dash.callback_context
    if not ctx.triggered:
        return 'violin'  # Default to violin plot
    button_id = ctx.triggered[0]['prop_id'].split('.')[0]
    if button_id == 'btn-violin':
        return 'violin'
    elif button_id == 'btn-box':
        return 'box'
    elif button_id == 'btn-scatter':
        return 'scatter'
    return 'violin'  # Fallback to default



from dash import html, dcc, Input, Output
from app import app
import plotly.express as px
import data_store


layout = html.Div([
    html.Div([
        html.Label("Column to plot"),
        dcc.Dropdown(
            id='violin-y-axis',
            placeholder="Select a column"
        ),
        html.Label("Group by"),
        dcc.Dropdown(
            id='violin-group-by',
            placeholder="Select a column"
        )
    ], style={'flex': '1', 'padding': '10px'}),

    html.Div([
        dcc.Graph(id='violin-plot')
    ], style={'flex': '2', 'padding': '10px'})
], style={'display': 'flex', 'width': '100%'})


@app.callback(
    Output('violin-y-axis', 'options'),
    Output('violin-y-axis', 'value'),
    Output('violin-group-by', 'options'),
    Output('violin-group-by', 'value'),
    Input('data-table', 'data')
)
def update_violin_dropdowns(data):
    df = data_store.all_data
    if not hasattr(data_store, 'all_data') or df is None:
        return [], None, [], None

    columns = [{'label': col, 'value': col} for col in df.columns]
    default_y_axis = 'Age' if 'Age' in df.columns else None
    default_group_by = 'Site' if 'Site' in df.columns else None
    return columns, default_y_axis, columns, default_group_by


@app.callback(
    Output('violin-plot', 'figure'),
    Input('violin-y-axis', 'value'),
    Input('violin-group-by', 'value')
)
def update_violin_plot(y_axis, group_by):
    if not y_axis:
        return {}
    data = data_store.all_data
    fig = px.violin(data, y=y_axis, color=group_by,
                    box=True, points='outliers') # points can be 'all', 'outliers', or False
    return fig



import os
from dash import dcc, html, Input, Output, State
from dash.exceptions import PreventUpdate
import pandas as pd
from app import app
import data_store


def create_directory_input():
    return html.Div([
        html.Div([
            html.Label("Directory path"),
            dcc.Input(
                id='directory-path-input',
                type='text',
                placeholder="Enter directory path",
                style={'width': '60%'},
                className="input input-bordered w-full max-w-xs"
            ),
            html.Button('Scan Directory', id='scan-button', className='button button-primary', n_clicks=0),
        ]),
        html.Div(id='file-list-container', children=[dcc.RadioItems(
            id='file-list',
            options=[],
            labelStyle={'display': 'block'},
            style={'overflowY': 'scroll', 'height': '200px'}  # Make it scrollable
        )]),  # Display files in directory
        html.Div([html.Button('Load Selected File', id='load-button', className='button button-primary', n_clicks=0)]),
        html.Div(id='file-contents-container')  # Display contents of file
    ], style={'display': 'flex', 'flex-direction': 'column', 'gap': '10px'})


@app.callback(
    Output('file-list', 'options'),
    Input('scan-button', 'n_clicks'),
    State('directory-path-input', 'value')
)
def scan_directory(n_clicks, directory_path):
    if not n_clicks or not directory_path:
        raise PreventUpdate

    # Check if the directory exists
    if not os.path.isdir(directory_path):
        return html.Div(["Directory not found. Please enter a valid path."], style={'color': 'red'})

    # List files in the directory
    files = os.listdir(directory_path)

    return [{'label': file, 'value': file} for file in files]


@app.callback(
    Output('file-contents-container', 'children'),
    Input('load-button', 'n_clicks'),
    State('directory-path-input', 'value'),
    State('file-list', 'value')
)
def load_file(n_clicks, directory_path, selected_file):
    if n_clicks == 0 or not selected_file:
        raise PreventUpdate

    # Load the file
    file_path = os.path.join(directory_path, selected_file)
    try:
        data_store.all_data = pd.read_csv(file_path)
    except Exception as e:
        return html.Div([f"Error loading file: {e}"], style={'color': 'red'})

    return html.Div([
        html.Span(f"Loaded {selected_file}")
    ])



import pandas as pd
from dash import Input, Output, dash_table
from dash.exceptions import PreventUpdate
from app import app
import data_store


def create_data_table():
    return dash_table.DataTable(
        id='data-table',
        columns=[
            {'name': 'participant_id', 'id': 'participant_id', 'type': 'text'},
            {'name': 'ID', 'id': 'ID', 'type': 'text'},
            {'name': 'Age', 'id': 'Age', 'type': 'numeric'},
            {'name': 'Sex', 'id': 'Sex', 'type': 'text'},
            {'name': 'Site', 'id': 'Site', 'type': 'text'}
        ],
        data=[],
        filter_action='native',
        sort_action='native',
        sort_mode='multi',
        page_action='native',  # Enable pagination
        page_size=20
    )

@app.callback(
    Output('data-table', 'data'),
    Output('data-table', 'columns'),
    Input('file-contents-container', 'children')
)
def update_table(data):
    if data is None:
        raise PreventUpdate

    df = data_store.all_data
    columns = [{'name': col, 'id': col} for col in df.columns]
    return df.to_dict('records'), columns
